pub struct SeedConnectOutcome {
pub attempted: usize,
pub connected: usize,
}Expand description
Outcome of attempting to connect to the configured seeds (R1).
Fields
attempted: usizeNumber of seeds dialed.
connected: usizeNumber of seeds that completed the distribution handshake.
Implementations
Sourceimpl SeedConnectOutcome
impl SeedConnectOutcome
Sourcepub const fn is_satisfied(&self) -> bool
pub const fn is_satisfied(&self) -> bool
True when at least one seed was reachable, or there were no seeds to dial (a lone bootstrap node forms a cluster of one and is not a join failure).