pub enum ReadinessCondition {
ConfigLoaded,
ListenerBound,
ClusterMembershipEstablished,
}Expand description
Readiness conditions that can prevent a server from receiving traffic.
Variants
ConfigLoaded
Configuration has not completed loading and validation.
ListenerBound
The main wire protocol listener is not bound and accepting traffic.
ClusterMembershipEstablished
Cluster configuration is present but membership is not established.