pub struct ReadinessStatus {
pub ready: bool,
pub unmet_conditions: Vec<ReadinessCondition>,
}Expand description
Result of the server readiness probe.
Fields
ready: boolTrue only when all applicable startup gates are satisfied.
unmet_conditions: Vec<ReadinessCondition>Startup gates that are not yet satisfied, in stable evaluation order.
Implementations
Sourceimpl ReadinessStatus
impl ReadinessStatus
Sourcepub fn from_unmet_conditions(unmet_conditions: Vec<ReadinessCondition>) -> Self
pub fn from_unmet_conditions(unmet_conditions: Vec<ReadinessCondition>) -> Self
Creates a readiness status from unmet startup gates.