pub struct SharedReadinessState { /* private fields */ }Expand description
Thread-safe readiness state shared with the HTTP endpoint server.
Implementations
Sourcepub fn new(initial: ReadinessState) -> Self
pub fn new(initial: ReadinessState) -> Self
Creates a shared readiness state from an initial startup snapshot.
Sourcepub fn snapshot(&self) -> ReadinessState
pub fn snapshot(&self) -> ReadinessState
Returns a consistent snapshot of the current readiness flags.
Sourcepub fn set_config_loaded(&self, loaded: bool)
pub fn set_config_loaded(&self, loaded: bool)
Updates whether configuration loading and validation completed.
Sourcepub fn set_listener_bound(&self, bound: bool)
pub fn set_listener_bound(&self, bound: bool)
Updates whether the main wire protocol listener is bound.
Sourcepub fn set_cluster_configured(&self, configured: bool)
pub fn set_cluster_configured(&self, configured: bool)
Updates whether cluster configuration is present.
Sourcepub fn set_cluster_membership_established(&self, established: bool)
pub fn set_cluster_membership_established(&self, established: bool)
Updates whether clustered membership is established.