pub struct HealthServerHandle { /* private fields */ }Expand description
Handle for a running health endpoint server.
Implementations
Sourceimpl HealthServerHandle
impl HealthServerHandle
Sourcepub const fn local_addr(&self) -> SocketAddr
pub const fn local_addr(&self) -> SocketAddr
Returns the bound address for the health endpoint server.
Sourcepub fn shutdown(self) -> Result<(), ServerError>
pub fn shutdown(self) -> Result<(), ServerError>
Stops the health endpoint server and waits for its worker thread to exit.
Errors
Returns ServerError::HealthEndpoint if the worker thread cannot be
joined cleanly or if the server loop recorded a serving error.