pub struct ConnectionHandle { /* private fields */ }Expand description
Handle for one supervised connection process.
Implementations
Sourceimpl ConnectionHandle
impl ConnectionHandle
Sourcepub const fn peer_addr(&self) -> Option<SocketAddr>
pub const fn peer_addr(&self) -> Option<SocketAddr>
Returns the peer address if it was available from the accepted stream.
Sourcepub fn request_crash(&self) -> Result<(), ServerError>
pub fn request_crash(&self) -> Result<(), ServerError>
Requests an error exit for tests and supervisor control paths.
Errors
Returns ServerError when the process is no longer live.