pub enum ParticipantDispatchError {
InvalidGenericFrame,
Semantic(ParticipantSemanticError),
Encode(CodecError),
}Expand description
Failure after a generic frame has entered participant dispatch.
Variants
InvalidGenericFrame
The preserved generic frame could not represent a canonical participant frame.
Semantic(ParticipantSemanticError)
The semantic handler could not produce a protocol value.
Encode(CodecError)
The crate-produced value could not be encoded into the generic transport.