pub enum ParticipantIngress {
NotParticipant,
Request(ClientRequest),
Rejected(ParticipantTransportRejected),
InvalidGenericFrame,
}Expand description
Result of classifying one preserved generic frame through the shared gate.
Variants
NotParticipant
The generic frame is not assigned to participant traffic.
Request(ClientRequest)
A structurally valid and authorized client request.
Rejected(ParticipantTransportRejected)
Exact pre-semantic rejection selected by liminal-protocol.
InvalidGenericFrame
A locally fabricated generic frame could not be represented canonically.