encode_server_push

Function encode_server_push 

pub fn encode_server_push(push: ServerPush) -> Result<Frame, CodecError>
Encodes one crate-produced server push into the participant generic frame on the protocol-owned generic stream zero.

Errors

Returns the shared codec error if the typed push cannot be encoded.