pub fn encode_server_value(value: ServerValue) -> Result<Frame, CodecError>Expand description
Encodes one crate-produced semantic value into the existing generic frame.
Errors
Returns the shared codec error if the typed value cannot be encoded.
pub fn encode_server_value(value: ServerValue) -> Result<Frame, CodecError>Encodes one crate-produced semantic value into the existing generic frame.
Returns the shared codec error if the typed value cannot be encoded.