pub fn run(config_path: &Path) -> Result<(), ServerError>Expand description
Starts the server deployment wrapper for the supplied configuration path.
Errors
Returns ServerError when a later server lifecycle phase fails.
pub fn run(config_path: &Path) -> Result<(), ServerError>Starts the server deployment wrapper for the supplied configuration path.
Returns ServerError when a later server lifecycle phase fails.