Module shutdown

Module shutdown 

Structs

ShutdownHandle
Idempotent shutdown activation handle shared by the runtime and signal thread.
SignalShutdownRegistration
Process-global OS signal registration for graceful shutdown.

Functions

register_signal_handlers
Registers SIGTERM and SIGINT handlers that initiate the supplied handle.
run_shutdown_sequence
Runs the graceful shutdown sequence after the handle has been activated.