Skip to main contentModule types
Source - AuthConfig
- Connection authentication configuration.
- ChannelDef
- Declarative channel definition loaded from server configuration.
- ClusterConfig
- Beamr distribution cluster configuration for standalone deployment.
- LimitsConfig
- Operational bounds (5, scout Q4 — rule-2 items).
- LoadedSchema
- A channel’s JSON Schema document as loaded from disk during config validation.
- RoutingRuleDef
- Declarative routing rule definition loaded from server configuration.
- ServerConfig
- Declarative configuration for the standalone liminal server wrapper.
- ServicesConfig
- Service construction profile selection (D2).
- ServiceProfile
- Which connection-services adapter the server constructs (D2).
- DEFAULT_COOKIE
- Default beamr distribution handshake cookie, used when the operator does not
configure one. Mirrors beamr’s own
beamr::distribution::DEFAULT_COOKIE.