Re-exports
pub use notifier::ConnectionNotifier;pub use services::ChannelCluster;pub use services::ConnectionServices;pub use services::ConnectionSubscription;pub use services::LiminalConnectionServices;pub use services::PublishOutcome;pub use services::build_connection_services;
Modules
Structs
- Connection
Conversation - Library conversation resource owned by a single connection process.
- Connection
Handle - Handle for one supervised connection process.
- Connection
Supervisor - Supervisor that owns the beamr scheduler for per-connection processes.
- Push
Reply Awaiter - Awaits the correlated reply to a single server-initiated push.
- WebSocket
Listener - Running sibling WebSocket listener.
- Worker
Front Door Services ConnectionServicesfor the worker front door: registration, correlated push/reply, and notifier-consumed reserved publishes only.
Traits
- Conversation
Resource - Marker for library conversation state owned by a single connection process.