Module connection

Module connection 

Re-exports

pub use notifier::ConnectionNotifier;
pub use services::ChannelCluster;
pub use services::ConnectionServices;
pub use services::ConnectionSubscription;
pub use services::LiminalConnectionServices;
pub use services::PublishOutcome;

Modules

notifier
Connection-keyed notifier hook for worker registration lifecycle.
services

Structs

ConnectionConversation
Library conversation resource owned by a single connection process.
ConnectionHandle
Handle for one supervised connection process.
ConnectionSupervisor
Supervisor that owns the beamr scheduler for per-connection processes.
PushReplyAwaiter
Awaits the correlated reply to a single server-initiated push.

Traits

ConversationResource
Marker for library conversation state owned by a single connection process.