SubscriptionResource

Trait SubscriptionResource 

pub trait SubscriptionResource: Debug + Send {
    // Required method
    fn unsubscribe(self: Box<Self>) -> Result<(), ServerError>;
}
Marker for resources retained by a connection process until unsubscribe.

Required Methods

fn unsubscribe(self: Box<Self>) -> Result<(), ServerError>

Releases the library subscription resource.

Errors

Returns ServerError when the liminal library reports an unsubscribe failure.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors